from robots import RobotRT, RobotRRR

import unittest
import numpy as np
import numpy.testing

rtol = 1e-6
atol = 1e-3


class TestRobotRT(unittest.TestCase):
    @classmethod
    def setUp(self):
        self.model = RobotRT()

    def test_mgd_rt_config0(self):
        joints = [0, 0]
        received = self.model.computeMGD(joints)
        expected = np.array([0.2, -0.275])
        np.testing.assert_allclose(received, expected, rtol, atol)

    def test_mgd_rt_config1(self):
        joints = [np.pi/2, 0.1]
        received = self.model.computeMGD(joints)
        expected = np.array([0.275, 0.3])
        np.testing.assert_allclose(received, expected, rtol, atol)


class TestRRRRobot(unittest.TestCase):
    @classmethod
    def setUp(self):
        self.model = RobotRRR()

    def test_mgd_rrr_config0(self):
        joints = [0, 0, 0]
        received = self.model.computeMGD(joints)
        expected = np.array([0, 1.225, 1.025])
        np.testing.assert_allclose(received, expected, rtol, atol)

    def test_mgd_rrr_config1(self):
        joints = np.array([np.pi/2, np.pi/2, -np.pi/2])
        received = self.model.computeMGD(joints)
        expected = np.array([-0.825, 0.0, 1.425])
        np.testing.assert_allclose(received, expected, rtol, atol)
